## 🔍 YGoogleSearch

📋 Google arama motoru üzerinde, verilen sorgunun sonuçlarını dosyaya raporlar.

## 🎌 Kullanım Notları

- ✨ İsterseniz, belirli **html durum kodlarına** sahip olan bağlantıları raporlar
- 🆘 Kullanım detayları için `ygooglesearch -h` yazın

## 📜 URL Dosyası

- 📃 Url dosyası her url bir satırda olacak şekilde tanımlıdır
- 🔍 Url dosyanız [Remove outdated content](https://www.google.com/webmasters/tools/removals) alanındaki urller olmalıdır

> 🔌 [Table Capture](https://chrome.google.com/webstore/detail/table-capture/iebpjdmgckacbodjpijphcplhebcmeop) eklentisi ile urlleri alabilirsiniz

```txt
https://ai.yemreak.com/x-arastirmalarim
https://python.yemreak.com/9-ipython
https://python.yemreak.com/1-giris
https://wiki.yemreak.com/web/notlar
https://windows.yemreak.com/giris/dizinler
```


## 💖 Destek ve İletişim

​[​![Github](../.github/assets/github_32px.png)​](https://github.com/yedhrab) [​![LinkedIn](../.github/assets/linkedin_32px.png)​](https://www.linkedin.com/in/yemreak/) [​![Website](../.github/assets/geography_32px.png)​](https://yemreak.com/) [​![Mail](../.github/assets/gmail_32px.png)​](mailto:yemreak.com@gmail.com?subject=YGoogleSearch%20%7C%20GitHub)​

​[​![Patreon](../.github/assets/become_a_patron_32px.png)](https://www.patreon.com/yemreak/)

## 🔏 Lisans

**The** [**Apache 2.0 License**](https://choosealicense.com/licenses/apache-2.0/) **©️ Yunus Emre Ak**

![YEmreAk](../.github/assets/ysigniture-trans.png)

